var crypto = require('crypto');

/**
 * 获取以X-CA-开头的keys
 */
function headersKeysSort(headers) {
    var keys = [];
    for (var key in headers) {
        if (!/(Accept|Content-MD5|Content-Type|Date)/.test(key)) {
            keys.push(key);
        }
    }
    return keys.sort();
}

function buildUrl(method, url, params, data) {
    var keys = [];
    if (!data) {
        for (var key in params) {
            keys.push(key + "=" + params[key]);
        }
    }
    return url + (keys.length > 0 ? '?' + keys.sort().join('&') : '');
}

function sign(signString, secret) {
    return crypto.createHmac('sha256', secret).update(signString, 'utf8').digest('base64');
}

function md5(content) {
    return crypto.createHash('md5').update(content, 'utf8').digest('base64');
}

function signString(method, headers, url, params, data) {
    var list = [];

    method = method.toUpperCase();
    list.push(method);
    if (!headers['Accept'])
        headers['Accept'] = '*/*'
    list.push(headers['Accept']);

    if (!headers['Content-Type']) {
        if (!data) {
            headers['Content-Type'] = 'application/x-www-form-urlencoded;charset=UTF-8';
        } else {
            headers['Content-Type'] = 'text/plain;charset=UTF-8';
        }
    }

    list.push(headers['Content-Type']);

    if (headers['Date'])
        list.push(headers['Date']);

    var keys = headersKeysSort(headers);
    for (var i = 0; i < keys.length; i++) {
        list.push(keys[i].toLowerCase() + ":" + headers[keys[i]]);
    }

    headers['X-Ca-Signature-Headers'] = keys.join(',').toLowerCase();

    list.push(buildUrl(method, url, params, data));

    return list.join('\n');
}

function client(appKey, secret) {

    this.signHeader = function (url, urlParams, method, headers, params, data) {
        url = url.replace(/https?:\/\/[\w.]+(:[0-9]*)?/, '');
        if (urlParams) {
            for (var key in urlParams) {
                url = url.replace(key, urlParams[key]);
            }
        }
        headers = headers || {};
        headers['X-Ca-Timestamp'] = Date.parse(new Date());
        headers['X-Ca-Key'] = appKey;
        var _signString = signString(method, headers, url, params, data);
        headers['X-Ca-Signature'] = sign(_signString, secret);
        return headers;
    }

    return this;
}

module.exports = client;